diff scripts/miscellaneous/nthargout.m @ 30893:e1788b1a315f

maint: Use "fcn" as preferred abbreviation for "function" in m-files. * accumarray.m, accumdim.m, quadl.m, quadv.m, randi.m, structfun.m, __is_function__.m, uigetfile.m, uimenu.m, uiputfile.m, doc_cache_create.m, colorspace_conversion_input_check.m, imageIO.m, argnames.m, vectorize.m, vectorize.m, normest1.m, inputname.m, nthargout.m, display_info_file.m, decic.m, ode15i.m, ode15s.m, ode23.m, ode23s.m, ode45.m, odeset.m, check_default_input.m, integrate_adaptive.m, ode_event_handler.m, runge_kutta_23.m, runge_kutta_23s.m, runge_kutta_45_dorpri.m, runge_kutta_interpolate.m, starting_stepsize.m, __all_opts__.m, fminbnd.m, fminsearch.m, fminunc.m, fsolve.m, fzero.m, sqp.m, fplot.m, plotyy.m, __bar__.m, __ezplot__.m, flat_entry.html, profexport.m, movfun.m, bicg.m, bicgstab.m, cgs.m, eigs.m, gmres.m, pcg.m, __alltohandles__.m, __sprand__.m, qmr.m, tfqmr.m, dump_demos.m: Replace "func", "fun", "fn" in documentation and variable names with "fcn".
author Rik <rik@octave.org>
date Mon, 04 Apr 2022 18:14:56 -0700
parents 5d3faba0342e
children 96f751f8392c
line wrap: on
line diff
--- a/scripts/miscellaneous/nthargout.m	Mon Apr 04 11:22:26 2022 -0700
+++ b/scripts/miscellaneous/nthargout.m	Mon Apr 04 18:14:56 2022 -0700
@@ -24,13 +24,13 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {@var{arg} =} nthargout (@var{n}, @var{func}, @dots{})
-## @deftypefnx {} {@var{arg} =} nthargout (@var{n}, @var{ntot}, @var{func}, @dots{})
+## @deftypefn  {} {@var{arg} =} nthargout (@var{n}, @var{fcn}, @dots{})
+## @deftypefnx {} {@var{arg} =} nthargout (@var{n}, @var{ntot}, @var{fcn}, @dots{})
 ## Return the @var{n}th output argument of the function specified by the
 ## function handle or string @var{func}.
 ##
 ## Any additional arguments are passed directly to @var{func}.  The total
 ## number of arguments to call @var{func} with can be passed in @var{ntot}; by
 ## default @var{ntot} is @var{n}.  The input @var{n} can also be a vector of
 ## indices of the output, in which case the output will be a cell array of the
 ## requested output arguments.
@@ -79,12 +79,12 @@
 
   if (is_function_handle (varargin{1}) || ischar (varargin{1}))
     ntot = max (n(:));
-    func = varargin{1};
+    fcn = varargin{1};
     args = varargin(2:end);
   elseif (isnumeric (varargin{1})
           && (is_function_handle (varargin{2}) || ischar (varargin{2})))
     ntot = varargin{1};
-    func = varargin{2};
+    fcn = varargin{2};
     args = varargin(3:end);
   else
     print_usage ();
@@ -97,7 +97,7 @@
   outargs = cell (1, ntot);
 
   try
-    [outargs{:}] = feval (func, args{:});
+    [outargs{:}] = feval (fcn, args{:});
     if (numel (n) > 1)
       arg = outargs(n);
     else
@@ -24,13 +24,13 @@
 ## Return the @var{n}th output argument of the function specified by the
-## function handle or string @var{func}.
+## function handle or string @var{fcn}.
 ##
@@ -24,13 +24,13 @@
 ##
-## Any additional arguments are passed directly to @var{func}.  The total
-## number of arguments to call @var{func} with can be passed in @var{ntot}; by
+## Any additional arguments are passed directly to @var{fcn}.  The total
+## number of arguments to call @var{fcn} with can be passed in @var{ntot}; by
 ## default @var{ntot} is @var{n}.  The input @var{n} can also be a vector of
 ## indices of the output, in which case the output will be a cell array of the